@@ -39,17 +39,84 @@ _PROFILE_1 = 2
 _PROFILE_3 = 3
 _PROFILE_4 = 4
 
-_KNOWN_PROFILES = [_NO_PROFILE, _PROFILE_0, _PROFILE_1, _PROFILE_3, _PROFILE_4]
+# no profile, conform to 15444-1
+_PROFILE_NONE = 0x0000
+
+# Profile 0 as described in 15444-1,Table A.45
+_PROFILE_0 = 0x0001
+
+# Profile 1 as described in 15444-1,Table A.45
+_PROFILE_1 = 0x0002
+
+# At least 1 extension defined in 15444-2 (Part-2)
+_PROFILE_PART2 = 0x8000
+
+# 2K cinema profile defined in 15444-1 AMD1
+_PROFILE_CINEMA_2K = 0x0003
+
+# 4K cinema profile defined in 15444-1 AMD1
+_PROFILE_CINEMA_4K = 0x0004
+
+# Scalable 2K cinema profile defined in 15444-1 AMD2
+_PROFILE_CINEMA_S2K = 0x0005
+
+# Scalable 4K cinema profile defined in 15444-1 AMD2
+_PROFILE_CINEMA_S4K = 0x0006
+
+# Long term storage cinema profile defined in 15444-1 AMD2
+_PROFILE_CINEMA_LTS = 0x0007
+
+# Single Tile Broadcast profile defined in 15444-1 AMD3
+_PROFILE_BC_SINGLE = 0x0100
+
+# Multi Tile Broadcast profile defined in 15444-1 AMD3
+_PROFILE_BC_MULTI = 0x0200
+
+# Multi Tile Reversible Broadcast profile defined in 15444-1 AMD3
+_PROFILE_BC_MULTI_R = 0x0300
+
+# 2K Single Tile Lossy IMF profile defined in 15444-1 AMD 8
+_PROFILE_IMF_2K = 0x0400
+
+# 4K Single Tile Lossy IMF profile defined in 15444-1 AMD 8
+_PROFILE_IMF_4K = 0x0500
+
+# 8K Single Tile Lossy IMF profile defined in 15444-1 AMD 8
+_PROFILE_IMF_8K = 0x0600
+
+# 2K Single/Multi Tile Reversible IMF profile defined in 15444-1 AMD 8
+_PROFILE_IMF_2K_R = 0x0700
+
+# 4K Single/Multi Tile Reversible IMF profile defined in 15444-1 AMD 8
+_PROFILE_IMF_4K_R = 0x0800
+
+# 8K Single/Multi Tile Reversible IMF profile defined in 15444-1 AMD 8
+_PROFILE_IMF_8K_R = 0x0900
 
 # How to display the codestream profile.
 _CAPABILITIES_DISPLAY = {
-    _NO_PROFILE: 'no profile',
+    _PROFILE_NONE: 'no profile',
     _PROFILE_0: '0',
     _PROFILE_1: '1',
-    _PROFILE_3: 'Cinema 2K',
-    _PROFILE_4: 'Cinema 4K',
+    _PROFILE_PART2: 'at least 1 extension defined in 15444-2 (Part-2)',
+    _PROFILE_CINEMA_2K: '2K cinema',
+    _PROFILE_CINEMA_4K: '4K cinema',
+    _PROFILE_CINEMA_S2K: 'scalable 2K cinema',
+    _PROFILE_CINEMA_S4K: 'scalable 4K cinema',
+    _PROFILE_CINEMA_LTS: 'long term storage cinema',
+    _PROFILE_BC_SINGLE: 'single tile broadcast',
+    _PROFILE_BC_MULTI: 'multi tile broadcast',
+    _PROFILE_BC_MULTI_R: 'multi tile reversible broadcast',
+    _PROFILE_IMF_2K: '2K single tile lossy IMF',
+    _PROFILE_IMF_4K: '4K single tile lossy IMF',
+    _PROFILE_IMF_8K: '8K single tile lossy IMF',
+    _PROFILE_IMF_2K_R: '2K single/multi tile reversible IMF',
+    _PROFILE_IMF_4K_R: '4K single/multi tile reversible IMF',
+    _PROFILE_IMF_8K_R: '8K single/multi tile reversible IMF',
 }
 
+_KNOWN_PROFILES = _CAPABILITIES_DISPLAY.keys()
+
 
 class Codestream(object):
     """Container for codestream information.
@@ -1022,18 +1089,20 @@ class CODsegment(Segment):
             xform = _WAVELET_XFORM_DISPLAY[self.xform]
         except KeyError:
             xform = f'{self.xform} (invalid)'
-        msg = msg.format(with_without='with' if (self.scod & 1) else 'without',
-                         sop=((self.scod & 2) > 0),
-                         eph=((self.scod & 4) > 0),
-                         prog=progression_order,
-                         num_layers=self.layers,
-                         mct=mct_str,
-                         num_dlevels=self.num_res,
-                         cbh=int(self.code_block_size[0]),
-                         cbw=int(self.code_block_size[1]),
-                         xform=xform,
-                         precinct_size=self.precinct_size,
-                         code_block_context=_context_string(self.cstyle))
+        msg = msg.format(
+            with_without='with' if (self.scod & 1) else 'without',
+            sop=((self.scod & 2) > 0),
+            eph=((self.scod & 4) > 0),
+            prog=progression_order,
+            num_layers=self.layers,
+            mct=mct_str,
+            num_dlevels=self.num_res,
+            cbh=int(self.code_block_size[0]),
+            cbw=int(self.code_block_size[1]),
+            xform=xform,
+            precinct_size=self.precinct_size,
+            code_block_context=_context_string(self.cstyle)
+        )
 
         return msg
 
@@ -1106,8 +1175,9 @@ class CRGsegment(Segment):
         msg = Segment.__str__(self)
         msg += '\n    Vertical, Horizontal offset: '
         for j in range(len(self.xcrg)):
-            msg += ' ({0:.2f}, {1:.2f})'.format(self.ycrg[j] / 65535.0,
-                                                self.xcrg[j] / 65535.0)
+            msg += ' ({0:.2f}, {1:.2f})'.format(
+                self.ycrg[j] / 65535.0, self.xcrg[j] / 65535.0
+            )
         return msg
 
 
@@ -1198,13 +1268,15 @@ class PODsegment(Segment):
             except KeyError:
                 progorder = f'invalid value: {self.ppod[j]}'
 
-            msg += submsg.format(j,
-                                 self.rspod[j],
-                                 self.cspod[j],
-                                 self.lyepod[j],
-                                 self.repod[j],
-                                 self.cdpod[j],
-                                 progorder)
+            msg += submsg.format(
+                j,
+                self.rspod[j],
+                self.cspod[j],
+                self.lyepod[j],
+                self.repod[j],
+                self.cdpod[j],
+                progorder
+            )
 
         return msg.rstrip()
 
@@ -1559,28 +1631,30 @@ class SIZsegment(Segment):
         msg = Segment.__str__(self)
         msg += '\n'
 
-        msg += ('    Profile:  {profile}\n'
-                '    Reference Grid Height, Width:  ({height} x {width})\n'
-                '    Vertical, Horizontal Reference Grid Offset:  '
-                '({goy} x {gox})\n'
-                '    Reference Tile Height, Width:  ({tileh} x {tilew})\n'
-                '    Vertical, Horizontal Reference Tile Offset:  '
-                '({toy} x {tox})\n'
-                '    Bitdepth:  {bitdepth}\n'
-                '    Signed:  {signed}\n'
-                '    Vertical, Horizontal Subsampling:  {subsampling}')
+        msg += (
+            '    Profile:  {profile}\n'
+            '    Reference Grid Height, Width:  ({height} x {width})\n'
+            '    Vertical, Horizontal Reference Grid Offset:  ({goy} x {gox})\n'  # noqa : E501
+            '    Reference Tile Height, Width:  ({tileh} x {tilew})\n'
+            '    Vertical, Horizontal Reference Tile Offset:  ({toy} x {tox})\n'  # noqa : E501
+            '    Bitdepth:  {bitdepth}\n'
+            '    Signed:  {signed}\n'
+            '    Vertical, Horizontal Subsampling:  {subsampling}'
+        )
         try:
             profile = _CAPABILITIES_DISPLAY[self.rsiz]
         except KeyError:
-            profile = '{rsiz} (invalid)'.format(rsiz=self.rsiz)
-        msg = msg.format(profile=profile,
-                         height=self.ysiz, width=self.xsiz,
-                         goy=self.yosiz, gox=self.xosiz,
-                         tileh=self.ytsiz, tilew=self.xtsiz,
-                         toy=self.ytosiz, tox=self.xtosiz,
-                         bitdepth=self.bitdepth,
-                         signed=self.signed,
-                         subsampling=tuple(zip(self.yrsiz, self.xrsiz)))
+            profile = f'{self.rsiz} (invalid)'
+        msg = msg.format(
+            profile=profile,
+            height=self.ysiz, width=self.xsiz,
+            goy=self.yosiz, gox=self.xosiz,
+            tileh=self.ytsiz, tilew=self.xtsiz,
+            toy=self.ytosiz, tox=self.xtosiz,
+            bitdepth=self.bitdepth,
+            signed=self.signed,
+            subsampling=tuple(zip(self.yrsiz, self.xrsiz))
+        )
 
         return msg
 
@@ -1813,12 +1887,14 @@ def _context_string(context):
              'Predictable termination:  {4}',
              'Segmentation symbols:  {5}']
     msg += '\n            '.join(lines)
-    msg = msg.format(((context & 0x01) > 0),
-                     ((context & 0x02) > 0),
-                     ((context & 0x04) > 0),
-                     ((context & 0x08) > 0),
-                     ((context & 0x10) > 0),
-                     ((context & 0x20) > 0))
+    msg = msg.format(
+        ((context & 0x01) > 0),
+        ((context & 0x02) > 0),
+        ((context & 0x04) > 0),
+        ((context & 0x08) > 0),
+        ((context & 0x10) > 0),
+        ((context & 0x20) > 0)
+    )
     return msg
 
 
