@@ -7,10 +7,13 @@ import ctypes
 import queue
 import textwrap
 
+# 3rd party library imports
+import numpy as np
+
 # Local imports
 from ..config import glymur_config
 
-OPENJP2 = glymur_config()
+OPENJP2 = glymur_config('openjp2')
 
 
 class OpenJPEGLibraryError(IOError):
@@ -139,10 +142,9 @@ class PocType(ctypes.Structure):
     ]
 
     def __str__(self):
-        msg = "{0}:\n".format(self.__class__)
+        msg = f"{self.__class__}:\n"
         for field_name, _ in self._fields_:
-            msg += "    {0}: {1}\n".format(
-                field_name, getattr(self, field_name))
+            msg += f"    {field_name}: {getattr(self, field_name)}\n"
         return msg
 
 
@@ -210,10 +212,9 @@ class DecompressionParametersType(ctypes.Structure):
     ]
 
     def __str__(self):
-        msg = "{0}:\n".format(self.__class__)
+        msg = f"{self.__class__}:\n"
         for field_name, _ in self._fields_:
-            msg += "    {0}: {1}\n".format(
-                field_name, getattr(self, field_name))
+            msg += f"    {field_name}: {getattr(self, field_name)}\n"
         return msg
 
 
@@ -409,17 +410,17 @@ class CompressionParametersType(ctypes.Structure):
         _fields_.append(("rsiz", ctypes.c_uint16))
 
     def __str__(self):
-        msg = "{0}:\n".format(self.__class__)
+        msg = f"{self.__class__}:\n"
         for field_name, _ in self._fields_:
 
             if field_name == 'poc':
-                msg += "    numpocs: {0}\n".format(self.numpocs)
+                msg += f"    numpocs: {self.numpocs}\n"
 
             elif field_name in ['tcp_rates', 'tcp_distoratio']:
                 lst = []
                 arr = getattr(self, field_name)
                 lst = [arr[j] for j in range(self.tcp_numlayers)]
-                msg += "    {0}: {1}\n".format(field_name, lst)
+                msg += f"    {field_name}: {lst}\n"
 
             elif field_name in ['prcw_init', 'prch_init']:
                 pass
@@ -427,9 +428,9 @@ class CompressionParametersType(ctypes.Structure):
             elif field_name == 'res_spec':
                 prcw_init = [self.prcw_init[j] for j in range(self.res_spec)]
                 prch_init = [self.prch_init[j] for j in range(self.res_spec)]
-                msg += "    res_spec: {0}\n".format(self.res_spec)
-                msg += "    prch_init: {0}\n".format(prch_init)
-                msg += "    prcw_init: {0}\n".format(prcw_init)
+                msg += f"    res_spec: {self.res_spec}\n"
+                msg += f"    prch_init: {prch_init}\n"
+                msg += f"    prcw_init: {prcw_init}\n"
 
             elif field_name in [
                     'jpwl_hprot_tph_tileno', 'jpwl_hprot_tph',
@@ -437,11 +438,10 @@ class CompressionParametersType(ctypes.Structure):
                     'jpwl_sens_tph_tileno', 'jpwl_sens_tph']:
                 arr = getattr(self, field_name)
                 lst = [arr[j] for j in range(JPWL_MAX_NO_TILESPECS)]
-                msg += "    {0}: {1}\n".format(field_name, lst)
+                msg += f"    {field_name}: {lst}\n"
 
             else:
-                msg += "    {0}: {1}\n".format(
-                    field_name, getattr(self, field_name))
+                msg += f"    {field_name}: {getattr(self, field_name)}\n"
         return msg
 
 
@@ -488,10 +488,9 @@ class ImageCompType(ctypes.Structure):
         _fields_.append(("alpha", ctypes.c_uint16))
 
     def __str__(self):
-        msg = "{0}:\n".format(self.__class__)
+        msg = f"{self.__class__}:\n"
         for field_name, _ in self._fields_:
-            msg += "    {0}: {1}\n".format(
-                field_name, getattr(self, field_name))
+            msg += f"    {field_name}: {getattr(self, field_name)}\n"
         return msg
 
 
@@ -527,13 +526,13 @@ class ImageType(ctypes.Structure):
     ]
 
     def __str__(self):
-        msg = "{0}:\n".format(self.__class__)
+        msg = f"{self.__class__}:\n"
         for field_name, _ in self._fields_:
 
             if field_name == "numcomps":
-                msg += "    numcomps: {0}\n".format(self.numcomps)
+                msg += f"    numcomps: {self.numcomps}\n"
                 for j in range(self.numcomps):  # pragma: no cover
-                    msg += "        comps[#{0}]:\n".format(j)
+                    msg += f"        comps[#{j}]:\n"
                     msg += textwrap.indent(str(self.comps[j]), ' ' * 12)
 
             elif field_name == "comps":
@@ -541,8 +540,7 @@ class ImageType(ctypes.Structure):
                 pass
 
             else:
-                msg += "    {0}: {1}\n".format(
-                    field_name, getattr(self, field_name))
+                msg += f"    {field_name}: {getattr(self, field_name)}\n"
 
         return msg
 
@@ -577,10 +575,9 @@ class ImageComptParmType(ctypes.Structure):
     ]
 
     def __str__(self):
-        msg = "{0}:\n".format(self.__class__)
+        msg = f"{self.__class__}:\n"
         for field_name, _ in self._fields_:
-            msg += "    {0}: {1}\n".format(
-                field_name, getattr(self, field_name))
+            msg += f"    {field_name}: {getattr(self, field_name)}\n"
         return msg
 
 
@@ -661,8 +658,11 @@ def decode(codec, stream, image):
     RuntimeError
         If the OpenJPEG library routine opj_decode fails.
     """
-    OPENJP2.opj_decode.argtypes = [CODEC_TYPE, STREAM_TYPE_P,
-                                   ctypes.POINTER(ImageType)]
+    OPENJP2.opj_decode.argtypes = [
+        CODEC_TYPE,
+        STREAM_TYPE_P,
+        ctypes.POINTER(ImageType)
+    ]
     OPENJP2.opj_decode.restype = check_error
 
     OPENJP2.opj_decode(codec, stream, image)
@@ -691,19 +691,23 @@ def decode_tile_data(codec, tidx, data, data_size, stream):
     RuntimeError
         If the OpenJPEG library routine opj_decode fails.
     """
-    OPENJP2.opj_decode_tile_data.argtypes = [CODEC_TYPE,
-                                             ctypes.c_uint32,
-                                             ctypes.POINTER(ctypes.c_uint8),
-                                             ctypes.c_uint32,
-                                             STREAM_TYPE_P]
+    OPENJP2.opj_decode_tile_data.argtypes = [
+        CODEC_TYPE,
+        ctypes.c_uint32,
+        ctypes.POINTER(ctypes.c_uint8),
+        ctypes.c_uint32,
+        STREAM_TYPE_P
+    ]
     OPENJP2.opj_decode_tile_data.restype = check_error
 
     datap = data.ctypes.data_as(ctypes.POINTER(ctypes.c_uint8))
-    OPENJP2.opj_decode_tile_data(codec,
-                                 ctypes.c_uint32(tidx),
-                                 datap,
-                                 ctypes.c_uint32(data_size),
-                                 stream)
+    OPENJP2.opj_decode_tile_data(
+        codec,
+        ctypes.c_uint32(tidx),
+        datap,
+        ctypes.c_uint32(data_size),
+        stream
+    )
 
 
 def create_decompress(codec_format):
@@ -786,10 +790,12 @@ def get_decoded_tile(codec, stream, imagep, tile_index):
     RuntimeError
         If the OpenJPEG library routine opj_get_decoded_tile fails.
     """
-    OPENJP2.opj_get_decoded_tile.argtypes = [CODEC_TYPE,
-                                             STREAM_TYPE_P,
-                                             ctypes.POINTER(ImageType),
-                                             ctypes.c_uint32]
+    OPENJP2.opj_get_decoded_tile.argtypes = [
+        CODEC_TYPE,
+        STREAM_TYPE_P,
+        ctypes.POINTER(ImageType),
+        ctypes.c_uint32
+    ]
     OPENJP2.opj_get_decoded_tile.restype = check_error
 
     OPENJP2.opj_get_decoded_tile(codec, stream, imagep, tile_index)
@@ -899,14 +905,18 @@ def image_create(comptparms, clrspc):
     image : ImageType
         Reference to ImageType instance.
     """
-    OPENJP2.opj_image_create.argtypes = [ctypes.c_uint32,
-                                         ctypes.POINTER(ImageComptParmType),
-                                         COLOR_SPACE_TYPE]
+    OPENJP2.opj_image_create.argtypes = [
+        ctypes.c_uint32,
+        ctypes.POINTER(ImageComptParmType),
+        COLOR_SPACE_TYPE
+    ]
     OPENJP2.opj_image_create.restype = ctypes.POINTER(ImageType)
 
-    image = OPENJP2.opj_image_create(len(comptparms),
-                                     comptparms,
-                                     clrspc)
+    image = OPENJP2.opj_image_create(
+        len(comptparms),
+        comptparms,
+        clrspc
+    )
     return image
 
 
@@ -927,18 +937,49 @@ def image_tile_create(comptparms, clrspc):
     image : ImageType
         Reference to ImageType instance.
     """
-    ARGTYPES = [ctypes.c_uint32,
-                ctypes.POINTER(ImageComptParmType),
-                COLOR_SPACE_TYPE]
+    ARGTYPES = [
+        ctypes.c_uint32,
+        ctypes.POINTER(ImageComptParmType),
+        COLOR_SPACE_TYPE
+    ]
     OPENJP2.opj_image_tile_create.argtypes = ARGTYPES
     OPENJP2.opj_image_tile_create.restype = ctypes.POINTER(ImageType)
 
-    image = OPENJP2.opj_image_tile_create(len(comptparms),
-                                          comptparms,
-                                          clrspc)
+    image = OPENJP2.opj_image_tile_create(
+        len(comptparms),
+        comptparms,
+        clrspc
+    )
     return image
 
 
+def encoder_set_extra_options(codec, plt=False):
+    """Specify extra options for the encoder.
+
+    Wraps the openjp2 library function opj_encoder_set_extra_options.
+
+    Parameters
+    ----------
+    codec:  codec_t
+        The JPEG2000 codec to read.
+    plt : bool
+        If True, PLT marker segments indicating the length of each packet in
+        the tile-part header will be written.
+    """
+    ARGTYPES = [
+        CODEC_TYPE,
+        ctypes.POINTER(ctypes.c_char_p)
+    ]
+    OPENJP2.opj_encoder_set_extra_options.argtypes = ARGTYPES
+    OPENJP2.opj_encoder_set_extra_options.restype = check_error
+
+    arr = (ctypes.c_char_p * 2)()
+    arr[0] = 'PLT=YES'.encode('utf-8') if plt else 'PLT=NO'.encode('utf-8')
+    arr[1] = None
+
+    OPENJP2.opj_encoder_set_extra_options(codec, arr)
+
+
 def read_header(stream, codec):
     """Decodes an image header.
 
@@ -961,8 +1002,11 @@ def read_header(stream, codec):
     RuntimeError
         If the OpenJPEG library routine opj_read_header fails.
     """
-    ARGTYPES = [STREAM_TYPE_P, CODEC_TYPE,
-                ctypes.POINTER(ctypes.POINTER(ImageType))]
+    ARGTYPES = [
+        STREAM_TYPE_P,
+        CODEC_TYPE,
+        ctypes.POINTER(ctypes.POINTER(ImageType))
+    ]
     OPENJP2.opj_read_header.argtypes = ARGTYPES
     OPENJP2.opj_read_header.restype = check_error
 
@@ -1003,16 +1047,18 @@ def read_tile_header(codec, stream):
     RuntimeError
         If the OpenJPEG library routine opj_read_tile_header fails.
     """
-    ARGTYPES = [CODEC_TYPE,
-                STREAM_TYPE_P,
-                ctypes.POINTER(ctypes.c_uint32),
-                ctypes.POINTER(ctypes.c_uint32),
-                ctypes.POINTER(ctypes.c_int32),
-                ctypes.POINTER(ctypes.c_int32),
-                ctypes.POINTER(ctypes.c_int32),
-                ctypes.POINTER(ctypes.c_int32),
-                ctypes.POINTER(ctypes.c_uint32),
-                ctypes.POINTER(BOOL_TYPE)]
+    ARGTYPES = [
+        CODEC_TYPE,
+        STREAM_TYPE_P,
+        ctypes.POINTER(ctypes.c_uint32),
+        ctypes.POINTER(ctypes.c_uint32),
+        ctypes.POINTER(ctypes.c_int32),
+        ctypes.POINTER(ctypes.c_int32),
+        ctypes.POINTER(ctypes.c_int32),
+        ctypes.POINTER(ctypes.c_int32),
+        ctypes.POINTER(ctypes.c_uint32),
+        ctypes.POINTER(BOOL_TYPE)
+    ]
     OPENJP2.opj_read_tile_header.argtypes = ARGTYPES
     OPENJP2.opj_read_tile_header.restype = check_error
 
@@ -1024,25 +1070,29 @@ def read_tile_header(codec, stream):
     row1 = ctypes.c_int32()
     ncomps = ctypes.c_uint32()
     go_on = BOOL_TYPE()
-    OPENJP2.opj_read_tile_header(codec,
-                                 stream,
-                                 ctypes.byref(tile_index),
-                                 ctypes.byref(data_size),
-                                 ctypes.byref(col0),
-                                 ctypes.byref(row0),
-                                 ctypes.byref(col1),
-                                 ctypes.byref(row1),
-                                 ctypes.byref(ncomps),
-                                 ctypes.byref(go_on))
+    OPENJP2.opj_read_tile_header(
+        codec,
+        stream,
+        ctypes.byref(tile_index),
+        ctypes.byref(data_size),
+        ctypes.byref(col0),
+        ctypes.byref(row0),
+        ctypes.byref(col1),
+        ctypes.byref(row1),
+        ctypes.byref(ncomps),
+        ctypes.byref(go_on)
+    )
     go_on = bool(go_on.value)
-    return (tile_index.value,
-            data_size.value,
-            col0.value,
-            row0.value,
-            col1.value,
-            row1.value,
-            ncomps.value,
-            go_on)
+    return (
+        tile_index.value,
+        data_size.value,
+        col0.value,
+        row0.value,
+        col1.value,
+        row1.value,
+        ncomps.value,
+        go_on
+    )
 
 
 def set_decode_area(codec, image, start_x=0, start_y=0, end_x=0, end_y=0):
@@ -1067,19 +1117,62 @@ def set_decode_area(codec, image, start_x=0, start_y=0, end_x=0, end_y=0):
     RuntimeError
         If the OpenJPEG library routine opj_set_decode_area fails.
     """
-    OPENJP2.opj_set_decode_area.argtypes = [CODEC_TYPE,
-                                            ctypes.POINTER(ImageType),
-                                            ctypes.c_int32,
-                                            ctypes.c_int32,
-                                            ctypes.c_int32,
-                                            ctypes.c_int32]
+    OPENJP2.opj_set_decode_area.argtypes = [
+        CODEC_TYPE,
+        ctypes.POINTER(ImageType),
+        ctypes.c_int32,
+        ctypes.c_int32,
+        ctypes.c_int32,
+        ctypes.c_int32
+    ]
     OPENJP2.opj_set_decode_area.restype = check_error
 
-    OPENJP2.opj_set_decode_area(codec, image,
-                                ctypes.c_int32(start_x),
-                                ctypes.c_int32(start_y),
-                                ctypes.c_int32(end_x),
-                                ctypes.c_int32(end_y))
+    OPENJP2.opj_set_decode_area(
+        codec, image,
+        ctypes.c_int32(start_x),
+        ctypes.c_int32(start_y),
+        ctypes.c_int32(end_x),
+        ctypes.c_int32(end_y)
+    )
+
+
+def set_decoded_components(codec, comp_indices):
+    """Wraps openjp2 library function opj_set_decoded_components.
+
+    Restrict the number of components to decode.  This function should be
+    called right after read_header.
+
+    Parameters
+    ----------
+    codec : CODEC_TYPE
+        Codec initialized by create_decompress function.
+    comp_indices : list-like
+        The indices of the components to decode (relative to the codestream,
+        starting at 0).
+
+    Raises
+    ------
+    RuntimeError
+        If the OpenJPEG library routine opj_set_decoded_components fails.
+    """
+    comp_indices = np.uint32(comp_indices)
+    OPENJP2.opj_set_decoded_components.argtypes = [
+        CODEC_TYPE,
+        ctypes.c_uint32,
+        ctypes.POINTER(ctypes.c_uint32),
+        ctypes.c_int32
+    ]
+    OPENJP2.opj_set_decoded_components.restype = check_error
+
+    ncomps = len(comp_indices)
+    indices_p = comp_indices.ctypes.data_as(ctypes.POINTER(ctypes.c_uint32))
+
+    # This is always False (0) for now.
+    apply_color_xforms = ctypes.c_int32(0)
+
+    OPENJP2.opj_set_decoded_components(
+        codec, ncomps, indices_p, apply_color_xforms
+    )
 
 
 def set_default_decoder_parameters():
@@ -1159,9 +1252,11 @@ def set_error_handler(codec, handler, data=None):
     RuntimeError
         If the OpenJPEG library routine opj_set_error_handler fails.
     """
-    OPENJP2.opj_set_error_handler.argtypes = [CODEC_TYPE,
-                                              ctypes.c_void_p,
-                                              ctypes.c_void_p]
+    OPENJP2.opj_set_error_handler.argtypes = [
+        CODEC_TYPE,
+        ctypes.c_void_p,
+        ctypes.c_void_p
+    ]
     OPENJP2.opj_set_error_handler.restype = check_error
     OPENJP2.opj_set_error_handler(codec, handler, data)
 
@@ -1185,9 +1280,9 @@ def set_info_handler(codec, handler, data=None):
     RuntimeError
         If the OpenJPEG library routine opj_set_info_handler fails.
     """
-    OPENJP2.opj_set_info_handler.argtypes = [CODEC_TYPE,
-                                             ctypes.c_void_p,
-                                             ctypes.c_void_p]
+    OPENJP2.opj_set_info_handler.argtypes = [
+        CODEC_TYPE, ctypes.c_void_p, ctypes.c_void_p
+    ]
     OPENJP2.opj_set_info_handler.restype = check_error
     OPENJP2.opj_set_info_handler(codec, handler, data)
 
@@ -1211,9 +1306,9 @@ def set_warning_handler(codec, handler, data=None):
     RuntimeError
         If the OpenJPEG library routine opj_set_warning_handler fails.
     """
-    OPENJP2.opj_set_warning_handler.argtypes = [CODEC_TYPE,
-                                                ctypes.c_void_p,
-                                                ctypes.c_void_p]
+    OPENJP2.opj_set_warning_handler.argtypes = [
+        CODEC_TYPE, ctypes.c_void_p, ctypes.c_void_p
+    ]
     OPENJP2.opj_set_warning_handler.restype = check_error
 
     OPENJP2.opj_set_warning_handler(codec, handler, data)
@@ -1263,9 +1358,11 @@ def setup_encoder(codec, cparams, image):
     RuntimeError
         If the OpenJPEG library routine opj_setup_encoder fails.
     """
-    ARGTYPES = [CODEC_TYPE,
-                ctypes.POINTER(CompressionParametersType),
-                ctypes.POINTER(ImageType)]
+    ARGTYPES = [
+        CODEC_TYPE,
+        ctypes.POINTER(CompressionParametersType),
+        ctypes.POINTER(ImageType)
+    ]
     OPENJP2.opj_setup_encoder.argtypes = ARGTYPES
     OPENJP2.opj_setup_encoder.restype = check_error
     OPENJP2.opj_setup_encoder(codec, ctypes.byref(cparams), image)
@@ -1290,9 +1387,9 @@ def start_compress(codec, image, stream):
     RuntimeError
         If the OpenJPEG library routine opj_start_compress fails.
     """
-    OPENJP2.opj_start_compress.argtypes = [CODEC_TYPE,
-                                           ctypes.POINTER(ImageType),
-                                           STREAM_TYPE_P]
+    OPENJP2.opj_start_compress.argtypes = [
+        CODEC_TYPE, ctypes.POINTER(ImageType), STREAM_TYPE_P
+    ]
     OPENJP2.opj_start_compress.restype = check_error
 
     OPENJP2.opj_start_compress(codec, image, stream)
@@ -1321,8 +1418,9 @@ def stream_create_default_file_stream(fname, isa_read_stream):
     OPENJP2.opj_stream_create_default_file_stream.restype = STREAM_TYPE_P
     read_stream = 1 if isa_read_stream else 0
     file_argument = ctypes.c_char_p(fname.encode())
-    stream = OPENJP2.opj_stream_create_default_file_stream(file_argument,
-                                                           read_stream)
+    stream = OPENJP2.opj_stream_create_default_file_stream(
+        file_argument, read_stream
+    )
     return stream
 
 
@@ -1353,7 +1451,7 @@ def write_tile(codec, tile_index, data, *pargs):
     tile_index : int
         The index of the tile to write, zero-indexing assumed
     data : array
-        Image data arranged in usual C-order
+        Image data.  The memory layout is planar, not the usual C-order.
     data_size : int, optional
         Size of a tile in bytes.  If not provided, it will be inferred.
     stream : STREAM_TYPE_P
@@ -1372,19 +1470,23 @@ def write_tile(codec, tile_index, data, *pargs):
         data_size = data.nbytes
         stream = pargs[0]
 
-    OPENJP2.opj_write_tile.argtypes = [CODEC_TYPE,
-                                       ctypes.c_uint32,
-                                       ctypes.POINTER(ctypes.c_uint8),
-                                       ctypes.c_uint32,
-                                       STREAM_TYPE_P]
+    OPENJP2.opj_write_tile.argtypes = [
+        CODEC_TYPE,
+        ctypes.c_uint32,
+        ctypes.POINTER(ctypes.c_uint8),
+        ctypes.c_uint32,
+        STREAM_TYPE_P
+    ]
     OPENJP2.opj_write_tile.restype = check_error
 
     datap = data.ctypes.data_as(ctypes.POINTER(ctypes.c_uint8))
-    OPENJP2.opj_write_tile(codec,
-                           ctypes.c_uint32(int(tile_index)),
-                           datap,
-                           ctypes.c_uint32(int(data_size)),
-                           stream)
+    OPENJP2.opj_write_tile(
+        codec,
+        ctypes.c_uint32(int(tile_index)),
+        datap,
+        ctypes.c_uint32(int(data_size)),
+        stream
+    )
 
 
 def set_error_message(msg):
