@@ -12,29 +12,29 @@ License:  MIT
 import sys
 
 # Third party library imports ...
-from distutils.version import LooseVersion
+from packaging.version import parse
 import numpy as np
 
 # Local imports ...
 from .lib import openjp2 as opj2
+from .lib import tiff
 
 # Do not change the format of this next line!  Doing so risks breaking
 # setup.py
-version = "0.9.3"
-_sv = LooseVersion(version)
-version_tuple = _sv.version
+version = "0.9.7"
+
+version_tuple = parse(version).release
 
 openjpeg_version = opj2.version()
+openjpeg_version_tuple = parse(openjpeg_version).release
 
-_sv = LooseVersion(openjpeg_version)
-openjpeg_version_tuple = _sv.version
+tiff_version = tiff.getVersion()
 
-__doc__ = """\
-This is glymur **{glymur_version}**
+__doc__ = f"""\
+This is glymur **{version}**
 
-* OpenJPEG version:  **{openjpeg}**
-""".format(glymur_version=version,
-           openjpeg=openjpeg_version)
+* OpenJPEG version:  **{openjpeg_version}**
+"""
 
 info = f"""\
 Summary of glymur configuration
