@@ -13,6 +13,15 @@ try:
     _HAVE_GDAL = True
 except ModuleNotFoundError:
     _HAVE_GDAL = False
+try:
+    import skimage.data  # noqa : F401
+    import skimage.io  # noqa : F401
+    import skimage.metrics  # noqa : F401
+    HAVE_SCIKIT_IMAGE = True
+    HAVE_SCIKIT_IMAGE_MSG = None
+except ModuleNotFoundError:
+    HAVE_SCIKIT_IMAGE = False
+    HAVE_SCIKIT_IMAGE_MSG = 'scikit-image not available'
 import numpy as np
 
 # Local imports
@@ -21,12 +30,22 @@ import glymur
 # Require at least a certain version of openjpeg for running most tests.
 if glymur.version.openjpeg_version < '2.2.0':  # pragma: no cover
     OPENJPEG_NOT_AVAILABLE = True
-    OPENJPEG_NOT_AVAILABLE_MSG = ('A version of OPENJPEG of at least v2.2.0 '
-                                  'must be installed.')
+    OPENJPEG_NOT_AVAILABLE_MSG = (
+        'A version of OPENJPEG of at least v2.2.0 must be installed.'
+    )
 else:
     OPENJPEG_NOT_AVAILABLE = False
     OPENJPEG_NOT_AVAILABLE_MSG = None
 
+if glymur.version.tiff_version < '4.0.0':
+    TIFF_NOT_AVAILABLE = True
+    TIFF_NOT_AVAILABLE_MSG = (
+        'A version of TIFF of at least v4.0.0 must be installed.'
+    )
+else:
+    TIFF_NOT_AVAILABLE = False
+    TIFF_NOT_AVAILABLE_MSG = None
+
 
 class TestCommon(unittest.TestCase):
     """
@@ -45,6 +64,7 @@ class TestCommon(unittest.TestCase):
         self.temp_jp2_filename = self.test_dir_path / 'test.jp2'
         self.temp_j2k_filename = self.test_dir_path / 'test.j2k'
         self.temp_jpx_filename = self.test_dir_path / 'test.jpx'
+        self.temp_tiff_filename = self.test_dir_path / 'test.tif'
 
     def tearDown(self):
         shutil.rmtree(self.test_dir)
