@@ -5,11 +5,7 @@ Tests for general glymur functionality.
 import collections
 import datetime
 import doctest
-try:
-    import importlib.resources as ir
-except ImportError:  # pragma:  no cover
-    # before 3.7
-    import importlib_resources as ir
+import importlib.resources as ir
 from io import BytesIO
 import os
 import pathlib
@@ -24,12 +20,6 @@ import warnings
 # Third party library imports ...
 from lxml import etree as ET
 import numpy as np
-try:
-    import skimage.data
-    import skimage.metrics
-    _HAVE_SCIKIT_IMAGE = True
-except ModuleNotFoundError:
-    _HAVE_SCIKIT_IMAGE = False
 
 # Local imports
 import glymur
@@ -53,225 +43,12 @@ def load_tests(loader, tests, ignore):  # pragma: no cover
         # Can't do it on windows, temporary file issue.
         return tests
     if glymur.lib.openjp2.OPENJP2 is not None:
-        tests.addTests(doctest.DocTestSuite('glymur.jp2k',
-                                            tearDown=docTearDown))
+        tests.addTests(
+            doctest.DocTestSuite('glymur.jp2k', tearDown=docTearDown)
+        )
     return tests
 
 
-class SliceProtocolBase(fixtures.TestCommon):
-    """
-    Test slice protocol, i.e. when using [ ] to read image data.
-    """
-    @classmethod
-    def setUpClass(self):
-
-        self.jp2 = Jp2k(glymur.data.nemo())
-        self.jp2_data = self.jp2[:]
-        self.jp2_data_r1 = self.jp2[::2, ::2]
-
-        self.j2k = Jp2k(glymur.data.goodstuff())
-        self.j2k_data = self.j2k[:]
-
-        self.j2k_data_r1 = self.j2k[::2, ::2]
-        self.j2k_data_r5 = self.j2k[::32, ::32]
-
-
-@unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
-class TestSliceProtocolBaseWrite(SliceProtocolBase):
-
-    def test_write_ellipsis(self):
-        """
-        SCENARIO:  write image by specifying ellipsis in slice
-
-        EXPECTED RESULT:  image is validated
-        """
-        expected = self.j2k_data
-
-        j = Jp2k(self.temp_j2k_filename, shape=expected.shape)
-        j[...] = expected
-        actual = j[:]
-
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_basic_write(self):
-        """
-        SCENARIO:  write image by specifying image data in constructor
-
-        EXPECTED RESULT:  image is validated
-        """
-        expected = self.j2k_data
-
-        j = Jp2k(self.temp_j2k_filename, shape=expected.shape)
-        j[:] = expected
-        actual = j[:]
-
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_cannot_write_with_non_default_single_slice(self):
-        """
-        SCENARIO:  Write image using single non-default slices.  Only ':' is
-        currently valid as a single slice argument.
-
-        EXPECTED RESULT:  ValueError
-        """
-        j = Jp2k(self.temp_j2k_filename, shape=self.j2k_data.shape)
-        with self.assertRaises(ValueError):
-            j[slice(None, 0)] = self.j2k_data
-        with self.assertRaises(ValueError):
-            j[slice(0, None)] = self.j2k_data
-        with self.assertRaises(ValueError):
-            j[slice(0, 0, None)] = self.j2k_data
-        with self.assertRaises(ValueError):
-            j[slice(0, 640)] = self.j2k_data
-
-    def test_cannot_write_a_row(self):
-        """
-        SCENARIO:  Write image row by specifying slicing.  Only ':' is
-        currently valid as a single slice argument.
-
-        EXPECTED RESULT:  ValueError
-        """
-        j = Jp2k(self.temp_j2k_filename, shape=self.j2k_data.shape)
-        with self.assertRaises(ValueError):
-            j[5] = self.j2k_data
-
-    def test_cannot_write_a_pixel(self):
-        """
-        SCENARIO:  Write pixel by specifying slicing.  Only ':' is
-        currently valid as a single slice argument.
-
-        EXPECTED RESULT:  ValueError
-        """
-        j = Jp2k(self.temp_j2k_filename, shape=self.j2k_data.shape)
-        with self.assertRaises(ValueError):
-            j[25, 35] = self.j2k_data[25, 35]
-
-    def test_cannot_write_a_column(self):
-        """
-        SCENARIO:  Write column by specifying slicing.  Only ':' is
-        currently valid as a single slice argument.
-
-        EXPECTED RESULT:  ValueError
-        """
-        j = Jp2k(self.temp_j2k_filename, shape=self.j2k_data.shape)
-        with self.assertRaises(ValueError):
-            j[:, 25, :] = self.j2k_data[:, :25, :]
-
-    def test_cannot_write_a_band(self):
-        """
-        SCENARIO:  Write band by specifying slicing.  Only ':' is
-        currently valid as a single slice argument.
-
-        EXPECTED RESULT:  ValueError
-        """
-        j = Jp2k(self.temp_j2k_filename, shape=self.j2k_data.shape)
-        with self.assertRaises(ValueError):
-            j[:, :, 0] = self.j2k_data[:, :, 0]
-
-    def test_cannot_write_a_subarray(self):
-        """
-        SCENARIO:  Write area by specifying slicing.  Only ':' is
-        currently valid as a single slice argument.
-
-        EXPECTED RESULT:  ValueError
-        """
-        j = Jp2k(self.temp_j2k_filename, shape=self.j2k_data.shape)
-        with self.assertRaises(ValueError):
-            j[:25, :45, :] = self.j2k_data[:25, :25, :]
-
-
-@unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
-class TestSliceProtocolRead(SliceProtocolBase):
-
-    def test_resolution_strides_cannot_differ(self):
-        with self.assertRaises(ValueError):
-            # Strides in x/y directions cannot differ.
-            self.j2k[::2, ::3]
-
-    def test_resolution_strides_must_be_powers_of_two(self):
-        with self.assertRaises(ValueError):
-            self.j2k[::3, ::3]
-
-    def test_integer_index_in_3d(self):
-
-        for j in [0, 1, 2]:
-            band = self.j2k[:, :, j]
-            np.testing.assert_array_equal(self.j2k_data[:, :, j], band)
-
-    def test_slice_in_third_dimension(self):
-        actual = self.j2k[:, :, 1:3]
-        expected = self.j2k_data[:, :, 1:3]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_reduce_resolution_and_slice_in_third_dimension(self):
-        actual = self.j2k[::2, ::2, 1:3]
-        expected = self.j2k_data_r1[:, :, 1:3]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_retrieve_single_row(self):
-        actual = self.jp2[0]
-        expected = self.jp2_data[0]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_retrieve_single_pixel(self):
-        actual = self.jp2[0, 0]
-        expected = self.jp2_data[0, 0]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_retrieve_single_component(self):
-        actual = self.jp2[20, 20, 2]
-        expected = self.jp2_data[20, 20, 2]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_ellipsis_full_read(self):
-        actual = self.j2k[...]
-        expected = self.j2k_data
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_ellipsis_band_select(self):
-        actual = self.j2k[..., 0]
-        expected = self.j2k_data[..., 0]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_ellipsis_row_select(self):
-        actual = self.j2k[0, ...]
-        expected = self.j2k_data[0, ...]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_two_ellipsis_band_select(self):
-        actual = self.j2k[..., ..., 1]
-        expected = self.j2k_data[:, :, 1]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_two_ellipsis_row_select(self):
-        actual = self.j2k[1, ..., ...]
-        expected = self.j2k_data[1, :, :]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_two_ellipsis_and_full_slice(self):
-        actual = self.j2k[..., ..., :]
-        expected = self.j2k_data[:]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_single_slice(self):
-        rows = slice(3, 8)
-        actual = self.j2k[rows]
-        expected = self.j2k_data[3:8, :, :]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_region_rlevel5(self):
-        """
-        maximim rlevel
-
-        There seems to be a difference between version of openjpeg, as
-        openjp2 produces an image of size (16, 13, 3) and openjpeg produced
-        (17, 12, 3).
-        """
-        actual = self.j2k[5:533:32, 27:423:32]
-        expected = self.j2k_data_r5[1:17, 1:14]
-        np.testing.assert_array_equal(actual, expected)
-
-
 @unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
 @unittest.skipIf(glymur.version.openjpeg_version < '2.3.0',
                  "Requires as least v2.3.0")
@@ -282,6 +59,74 @@ class TestJp2k(fixtures.TestCommon):
         super(TestJp2k, self).setUp()
         glymur.reset_option('all')
 
+    def test_dtype_jp2(self):
+        """
+        Scenario:  An RGB image is read from a JP2 file.
+
+        Expected response:  the dtype property is np.uint8
+        """
+        j = Jp2k(self.jp2file)
+        self.assertEqual(j.dtype, np.uint8)
+
+    def test_dtype_j2k_uint16(self):
+        """
+        Scenario:  A uint16 monochrome image is read from a J2K file.
+
+        Expected response:  the dtype property is np.uint16
+        """
+        with ir.path('tests.data', 'uint16.j2k') as path:
+            j = Jp2k(path)
+        self.assertEqual(j.dtype, np.uint16)
+
+    def test_dtype_prec4_signd1(self):
+        """
+        Scenario:  A 4-bit signed image is read from a J2k file.
+
+        Expected response:  the dtype property is np.int8
+        """
+        with ir.path('tests.data', 'p0_03.j2k') as path:
+            j = Jp2k(path)
+        self.assertEqual(j.dtype, np.int8)
+
+    def test_dtype_inconsistent_bitdetph(self):
+        """
+        Scenario:  The image has different bitdepths in different components.
+
+        Expected response:  TypeError when accessing the dtype property.
+        """
+        with ir.path('tests.data', 'issue982.j2k') as path:
+            j = Jp2k(path)
+        with self.assertRaises(TypeError):
+            j.dtype
+
+    def test_ndims_jp2(self):
+        """
+        Scenario:  An RGB image is read from a JP2 file.
+
+        Expected response:  the ndim attribute/property is 3
+        """
+        j = Jp2k(self.jp2file)
+        self.assertEqual(j.ndim, 3)
+
+    def test_ndims_j2k(self):
+        """
+        Scenario:  An RGB image is read from a raw codestream.
+
+        Expected response:  the ndim attribute/property is 3
+        """
+        j = Jp2k(self.j2kfile)
+        self.assertEqual(j.ndim, 3)
+
+    def test_ndims_monochrome_j2k(self):
+        """
+        Scenario:  An monochrome image is read from a raw codestream.
+
+        Expected response:  the ndim attribute/property is 2
+        """
+        with ir.path('tests.data', 'p0_02.j2k') as path:
+            j = Jp2k(path)
+        self.assertEqual(j.ndim, 2)
+
     def test_read_bands_unequal_subsampling(self):
         """
         SCENARIO:  The read_bands method is used on an image with unequal
@@ -370,8 +215,9 @@ class TestJp2k(fixtures.TestCommon):
 
         channel_type = [COLOR, COLOR, COLOR]
         association = [BLUE, GREEN, RED]
-        cdef = glymur.jp2box.ChannelDefinitionBox(channel_type=channel_type,
-                                                  association=association)
+        cdef = glymur.jp2box.ChannelDefinitionBox(
+            channel_type=channel_type, association=association
+        )
         jp2h.box.append(cdef)
 
         boxes.append(jp2h)
@@ -472,8 +318,10 @@ class TestJp2k(fixtures.TestCommon):
         j2 = Jp2k(self.temp_j2k_filename, data=expdata, irreversible=True)
 
         codestream = j2.get_codestream()
-        self.assertEqual(codestream.segment[2].xform,
-                         glymur.core.WAVELET_XFORM_9X7_IRREVERSIBLE)
+        self.assertEqual(
+            codestream.segment[2].xform,
+            glymur.core.WAVELET_XFORM_9X7_IRREVERSIBLE
+        )
 
         actdata = j2[:]
         self.assertTrue(fixtures.mse(actdata[0], expdata[0]) < 0.38)
@@ -511,13 +359,34 @@ class TestJp2k(fixtures.TestCommon):
             with self.assertRaises(InvalidJp2kError):
                 Jp2k(path)
 
-    def test_file_not_present(self):
+    def test_read_from_a_file_that_does_not_exist(self):
         """Should error out if reading from a file that does not exist"""
         # Verify that we error out appropriately if not given an existing file
         # at all.
         filename = 'this file does not actually exist on the file system.'
-        with self.assertRaises(OSError):
-            Jp2k(filename)
+        j = Jp2k(filename)
+        with self.assertRaises(FileNotFoundError):
+            j[:]
+
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
+    def test_write_to_a_file_using_context_manager(self):
+        """
+        SCENARIO:  Write to a file using a context manager, read the data back
+        using a context manager.
+
+        EXPECTED RESULT: the data matches
+        """
+        expected = fixtures.skimage.data.astronaut()
+
+        j1 = Jp2k(self.temp_jp2_filename)
+        j1[:] = expected
+
+        j2 = Jp2k(self.temp_jp2_filename)
+        actual = j2[:]
+
+        np.testing.assert_array_equal(actual, expected)
 
     def test_codestream(self):
         """
@@ -805,18 +674,20 @@ class TestJp2k(fixtures.TestCommon):
                 # Write the ULST box.
                 # Length is 26, 1 UUID, hard code that UUID as zeros.
                 ulst_len = 26
-                write_buffer = struct.pack('>I4sHIIII', ulst_len, b'ulst',
-                                           int(1), int(0), int(0), int(0),
-                                           int(0))
+                write_buffer = struct.pack(
+                    '>I4sHIIII',
+                    ulst_len, b'ulst', int(1), int(0), int(0), int(0), int(0)
+                )
                 tfile.write(write_buffer)
 
                 # Write the URL box.
                 # Length is 16, version is one byte, flag is 3 bytes, url
                 # is the rest.
                 url_box_len = 16
-                write_buffer = struct.pack('>I4sBBBB',
-                                           url_box_len, b'url ',
-                                           int(0), int(0), int(0), int(0))
+                write_buffer = struct.pack(
+                    '>I4sBBBB',
+                    url_box_len, b'url ', int(0), int(0), int(0), int(0)
+                )
                 tfile.write(write_buffer)
                 write_buffer = struct.pack('>ssss', b'a', b'b', b'c', b'd')
                 tfile.write(write_buffer)
@@ -1040,9 +911,11 @@ class TestJp2k(fixtures.TestCommon):
                           'color media'))
         self.assertEqual(profile['Rendering Intent'], 'perceptual')
 
-        np.testing.assert_almost_equal(profile['Illuminant'],
-                                       (0.964203, 1.000000, 0.824905),
-                                       decimal=6)
+        np.testing.assert_almost_equal(
+            profile['Illuminant'],
+            (0.964203, 1.000000, 0.824905),
+            decimal=6
+        )
 
         self.assertEqual(profile['Creator'], 'JPEG')
 
@@ -1204,7 +1077,7 @@ class TestComponent(unittest.TestCase):
 
 @unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
 class TestJp2k_write(fixtures.MetadataBase):
-    """Write tests, can be run by versions 2.1"""
+    """Test writing Jpeg2000 files"""
 
     @classmethod
     def setUpClass(cls):
@@ -1273,7 +1146,9 @@ class TestJp2k_write(fixtures.MetadataBase):
             with self.assertRaises(InvalidJp2kError):
                 Jp2k(tfile.name, data=np.zeros((0, 256), dtype=np.uint8))
 
-    @unittest.skipIf(not _HAVE_SCIKIT_IMAGE, "No scikit-image found")
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
     def test_psnr_zero_value_not_last(self):
         """
         SCENARIO:  The PSNR keyword argument has a zero value, but it is not
@@ -1282,13 +1157,61 @@ class TestJp2k_write(fixtures.MetadataBase):
         EXPECTED RESULT:  RuntimeError
         """
         kwargs = {
-            'data': skimage.data.camera(),
+            'data': fixtures.skimage.data.camera(),
             'psnr': [0, 35, 40, 30],
         }
         with self.assertRaises(RuntimeError):
             Jp2k(self.temp_jp2_filename, **kwargs)
 
-    @unittest.skipIf(not _HAVE_SCIKIT_IMAGE, "No scikit-image found")
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
+    def test_plt_yes(self):
+        """
+        SCENARIO:  Use the plt keyword.
+
+        EXPECTED RESULT:  Plt segment is detected.
+        """
+        kwargs = {
+            'data': fixtures.skimage.data.camera(),
+            'plt': True
+        }
+        j = Jp2k(self.temp_jp2_filename, **kwargs)
+
+        codestream = j.get_codestream(header_only=False)
+
+        at_least_one_plt = any(
+            isinstance(seg, glymur.codestream.PLTsegment)
+            for seg in codestream.segment
+        )
+        self.assertTrue(at_least_one_plt)
+
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
+    def test_plt_no(self):
+        """
+        SCENARIO:  Use the plt keyword set to false.
+
+        EXPECTED RESULT:  Plt segment is not detected.
+        """
+        kwargs = {
+            'data': fixtures.skimage.data.camera(),
+            'plt': False
+        }
+        j = Jp2k(self.temp_jp2_filename, **kwargs)
+
+        codestream = j.get_codestream(header_only=False)
+
+        at_least_one_plt = any(
+            isinstance(seg, glymur.codestream.PLTsegment)
+            for seg in codestream.segment
+        )
+        self.assertFalse(at_least_one_plt)
+
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
     def test_psnr_non_zero_non_monotonically_decreasing(self):
         """
         SCENARIO:  The PSNR keyword argument is non-monotonically increasing
@@ -1297,13 +1220,15 @@ class TestJp2k_write(fixtures.MetadataBase):
         EXPECTED RESULT:  RuntimeError
         """
         kwargs = {
-            'data': skimage.data.camera(),
+            'data': fixtures.skimage.data.camera(),
             'psnr': [30, 35, 40, 30],
         }
         with self.assertRaises(RuntimeError):
             Jp2k(self.temp_jp2_filename, **kwargs)
 
-    @unittest.skipIf(not _HAVE_SCIKIT_IMAGE, "No scikit-image found")
+    @unittest.skipIf(
+        not fixtures.HAVE_SCIKIT_IMAGE, fixtures.HAVE_SCIKIT_IMAGE_MSG
+    )
     def test_psnr(self):
         """
         SCENARIO:  Four peak signal-to-noise ratio values are supplied, the
@@ -1312,7 +1237,7 @@ class TestJp2k_write(fixtures.MetadataBase):
         EXPECTED RESULT:  Four quality layers, the first should be lossless.
         """
         kwargs = {
-            'data': skimage.data.camera(),
+            'data': fixtures.skimage.data.camera(),
             'psnr': [30, 35, 40, 0],
         }
         with open(self.temp_jp2_filename, mode='wb') as tfile:
@@ -1328,8 +1253,8 @@ class TestJp2k_write(fixtures.MetadataBase):
             # warning
             warnings.simplefilter('ignore')
             psnr = [
-                skimage.metrics.peak_signal_noise_ratio(
-                    skimage.data.camera(), d[j]
+                fixtures.skimage.metrics.peak_signal_noise_ratio(
+                    fixtures.skimage.data.camera(), d[j]
                 )
                 for j in range(4)
             ]
@@ -1412,8 +1337,12 @@ class TestJp2k_write(fixtures.MetadataBase):
         size are present.  The precinct sizes validate.
         """
         with open(self.temp_j2k_filename, mode='wb') as tfile:
-            j = Jp2k(tfile.name, data=self.jp2_data, psnr=[30, 35, 40],
-                     cbsize=(16, 16), psizes=[(64, 64)])
+            j = Jp2k(
+                tfile.name,
+                data=self.jp2_data,
+                psnr=[30, 35, 40],
+                cbsize=(16, 16), psizes=[(64, 64)]
+            )
 
             codestream = j.get_codestream()
 
@@ -1426,14 +1355,16 @@ class TestJp2k_write(fixtures.MetadataBase):
         self.assertEqual(codestream.segment[2].num_res, 5)  # levels
         self.assertEqual(tuple(codestream.segment[2].code_block_size),
                          (16, 16))  # cblksz
-        self.verify_codeblock_style(codestream.segment[2].cstyle,
-                                    [False, False,
-                                     False, False, False, False])
+        self.verify_codeblock_style(
+            codestream.segment[2].cstyle,
+            [False, False, False, False, False, False]
+        )
         self.assertEqual(codestream.segment[2].xform,
                          glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-        self.assertEqual(codestream.segment[2].precinct_size,
-                         ((2, 2), (4, 4), (8, 8), (16, 16), (32, 32),
-                          (64, 64)))
+        self.assertEqual(
+            codestream.segment[2].precinct_size,
+            ((2, 2), (4, 4), (8, 8), (16, 16), (32, 32), (64, 64))
+        )
 
     def test_NR_ENC_Bretagne2_ppm_4_encode(self):
         """
@@ -1443,12 +1374,14 @@ class TestJp2k_write(fixtures.MetadataBase):
 
         """
         with open(self.temp_j2k_filename, mode='wb') as tfile:
-            j = Jp2k(tfile.name,
-                     data=self.jp2_data,
-                     psizes=[(128, 128)] * 3,
-                     cratios=[100, 20, 2],
-                     tilesize=(480, 640),
-                     cbsize=(32, 32))
+            j = Jp2k(
+                tfile.name,
+                data=self.jp2_data,
+                psizes=[(128, 128)] * 3,
+                cratios=[100, 20, 2],
+                tilesize=(480, 640),
+                cbsize=(32, 32)
+            )
 
             # Should be three layers.
             codestream = j.get_codestream()
@@ -1465,16 +1398,25 @@ class TestJp2k_write(fixtures.MetadataBase):
             self.assertEqual(codestream.segment[2].layers, 3)  # layers = 3
             self.assertEqual(codestream.segment[2].mct, 1)  # mct
             self.assertEqual(codestream.segment[2].num_res, 5)  # levels
-            self.assertEqual(tuple(codestream.segment[2].code_block_size),
-                             (32, 32))  # cblksz
-            self.verify_codeblock_style(codestream.segment[2].cstyle,
-                                        [False, False,
-                                         False, False, False, False])
-            self.assertEqual(codestream.segment[2].xform,
-                             glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
-            self.assertEqual(codestream.segment[2].precinct_size,
-                             ((16, 16), (32, 32), (64, 64), (128, 128),
-                              (128, 128), (128, 128)))
+            self.assertEqual(
+                tuple(codestream.segment[2].code_block_size),
+                (32, 32)
+            )  # cblksz
+            self.verify_codeblock_style(
+                codestream.segment[2].cstyle,
+                [False, False, False, False, False, False]
+            )
+            self.assertEqual(
+                codestream.segment[2].xform,
+                glymur.core.WAVELET_XFORM_5X3_REVERSIBLE
+            )
+            self.assertEqual(
+                codestream.segment[2].precinct_size,
+                (
+                    (16, 16), (32, 32), (64, 64), (128, 128), (128, 128),
+                    (128, 128)
+                )
+            )
 
     def test_NR_ENC_Bretagne2_ppm_5_encode(self):
         """
@@ -1498,14 +1440,15 @@ class TestJp2k_write(fixtures.MetadataBase):
             self.assertFalse(codestream.segment[2].scod & 4)  # no eph
             self.assertEqual(codestream.segment[2].prog_order,
                              glymur.core.PCRL)
-            self.assertEqual(codestream.segment[2].layers, 1)  # layers = 1
+            self.assertEqual(codestream.segment[2].layers, 1)
             self.assertEqual(codestream.segment[2].mct, 1)  # mct
             self.assertEqual(codestream.segment[2].num_res, 5)  # levels
             self.assertEqual(tuple(codestream.segment[2].code_block_size),
                              (64, 64))  # cblksz
-            self.verify_codeblock_style(codestream.segment[2].cstyle,
-                                        [False, False,
-                                         False, False, False, False])
+            self.verify_codeblock_style(
+                codestream.segment[2].cstyle,
+                [False, False, False, False, False, False]
+            )
             self.assertEqual(codestream.segment[2].xform,
                              glymur.core.WAVELET_XFORM_5X3_REVERSIBLE)
             self.assertEqual(codestream.segment[2].precinct_size,
@@ -1725,10 +1668,16 @@ class TestJp2k_write(fixtures.MetadataBase):
 
             codestream = jp2.box[3].codestream
 
-            kwargs = {'rsiz': 0, 'xysiz': (2592, 1456), 'xyosiz': (0, 0),
-                      'xytsiz': (2592, 1456), 'xytosiz': (0, 0),
-                      'bitdepth': (8, 8, 8), 'signed': (False, False, False),
-                      'xyrsiz': [(1, 1, 1), (1, 1, 1)]}
+            kwargs = {
+                'rsiz': 0,
+                'xysiz': (2592, 1456),
+                'xyosiz': (0, 0),
+                'xytsiz': (2592, 1456),
+                'xytosiz': (0, 0),
+                'bitdepth': (8, 8, 8),
+                'signed': (False, False, False),
+                'xyrsiz': [(1, 1, 1), (1, 1, 1)]
+            }
             self.verifySizSegment(codestream.segment[1],
                                   glymur.codestream.SIZsegment(**kwargs))
 
@@ -1762,10 +1711,16 @@ class TestJp2k_write(fixtures.MetadataBase):
 
             codestream = j.get_codestream(header_only=False)
 
-            kwargs = {'rsiz': 0, 'xysiz': (1024, 1024), 'xyosiz': (0, 0),
-                      'xytsiz': (1024, 1024), 'xytosiz': (0, 0),
-                      'bitdepth': (16,), 'signed': (False,),
-                      'xyrsiz': [(1,), (1,)]}
+            kwargs = {
+                'rsiz': 0,
+                'xysiz': (1024, 1024),
+                'xyosiz': (0, 0),
+                'xytsiz': (1024, 1024),
+                'xytosiz': (0, 0),
+                'bitdepth': (16,),
+                'signed': (False,),
+                'xyrsiz': [(1,), (1,)]
+            }
             self.verifySizSegment(codestream.segment[1],
                                   glymur.codestream.SIZsegment(**kwargs))
 
@@ -1800,8 +1755,10 @@ class TestJp2k_write(fixtures.MetadataBase):
             j = Jp2k(tfile.name, data=self.jp2_data, irreversible=True)
 
             codestream = j.get_codestream()
-            self.assertEqual(codestream.segment[2].xform,
-                             glymur.core.WAVELET_XFORM_9X7_IRREVERSIBLE)
+            self.assertEqual(
+                codestream.segment[2].xform,
+                glymur.core.WAVELET_XFORM_9X7_IRREVERSIBLE
+            )
 
     def test_cinema2K_with_others(self):
         """
@@ -2085,11 +2042,6 @@ class TestJp2k_write(fixtures.MetadataBase):
             self.assertEqual(codestream.segment[2].prog_order,
                              glymur.core.CPRL)
 
-
-@unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
-class TestJp2k_2_0(fixtures.TestCommon):
-    """Test suite requiring at least version 2.0"""
-
     def test_bad_area_parameter(self):
         """Should error out appropriately if given a bad area parameter."""
         j = Jp2k(self.jp2file)
@@ -2252,193 +2204,3 @@ class TestParsing(unittest.TestCase):
         self.assertIsNone(jp2c._codestream)
         jp2c.codestream
         self.assertIsNotNone(jp2c._codestream)
-
-
-@unittest.skipIf(OPENJPEG_NOT_AVAILABLE, OPENJPEG_NOT_AVAILABLE_MSG)
-class TestReadArea(unittest.TestCase):
-    """
-    Runs tests introduced in version 2.0+ or that pass only in 2.0+
-
-    These tests are only slightly different than their counterparts in the
-    OpenJPEG test suite.  The difference is in the file that is tested and
-    their extents.  The purpose is the same, though.
-    """
-    @classmethod
-    def setUpClass(self):
-
-        self.j2k = Jp2k(glymur.data.goodstuff())
-        self.j2k_data = self.j2k[:]
-        self.j2k_half_data = self.j2k[::2, ::2]
-        self.j2k_quarter_data = self.j2k[::4, ::4]
-
-    def test_NR_DEC_p1_04_j2k_43_decode(self):
-        actual = self.j2k[:800, :480]
-        expected = self.j2k_data
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_45_decode(self):
-        """
-        Get bottom right
-        """
-        actual = self.j2k[672:800, 352:480]
-        expected = self.j2k_data[672:800, 352:480]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_46_decode(self):
-        actual = self.j2k[500:800, 100:300]
-        expected = self.j2k_data[500:800, 100:300]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_47_decode(self):
-        actual = self.j2k[520:600, 260:360]
-        expected = self.j2k_data[520:600, 260:360]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_48_decode(self):
-        actual = self.j2k[520:660, 260:360]
-        expected = self.j2k_data[520:660, 260:360]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_49_decode(self):
-        actual = self.j2k[520:600, 360:400]
-        expected = self.j2k_data[520:600, 360:400]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_50_decode(self):
-        actual = self.j2k[:800:4, :480:4]
-        expected = self.j2k_quarter_data
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_51_decode(self):
-        """
-        NR_DEC_p1_04_j2k_51_decode
-
-        Original extents were
-
-        actual = self.j2k[640:768:4, 512:640:4]
-        expected = self.j2k_quarter_data[160:192, 128:160]
-
-        Just needed to shift the columns to the left to make it work with
-        our own image.
-        """
-        actual = self.j2k[640:768:4, 256:384:4]
-        expected = self.j2k_quarter_data[160:192, 64:96]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_53_decode(self):
-        actual = self.j2k[500:800:4, 100:300:4]
-        expected = self.j2k_quarter_data[125:200, 25:75]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_54_decode(self):
-        actual = self.j2k[520:600:4, 260:360:4]
-        expected = self.j2k_quarter_data[130:150, 65:90]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_55_decode(self):
-        actual = self.j2k[520:660:4, 260:360:4]
-        expected = self.j2k_quarter_data[130:165, 65:90]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_04_j2k_56_decode(self):
-        actual = self.j2k[520:600:4, 360:400:4]
-        expected = self.j2k_quarter_data[130:150, 90:100]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p1_06_j2k_70_decode(self):
-        actual = self.j2k[9:12:2, 9:12:2]
-        self.assertEqual(actual.shape, (1, 1, 3))
-
-    def test_NR_DEC_p1_06_j2k_71_decode(self):
-        actual = self.j2k[10:12:2, 4:10:2]
-        self.assertEqual(actual.shape, (1, 3, 3))
-
-    def test_NR_DEC_p1_06_j2k_72_decode(self):
-        ssdata = self.j2k[3:9:2, 3:9:2]
-        self.assertEqual(ssdata.shape, (3, 3, 3))
-
-    def test_NR_DEC_p1_06_j2k_73_decode(self):
-        ssdata = self.j2k[4:7:2, 4:7:2]
-        self.assertEqual(ssdata.shape, (2, 2, 3))
-
-    def test_NR_DEC_p1_06_j2k_74_decode(self):
-        ssdata = self.j2k[4:5:2, 4:5:2]
-        self.assertEqual(ssdata.shape, (1, 1, 3))
-
-    def test_NR_DEC_p1_06_j2k_75_decode(self):
-        """
-        SCENARIO:  Try to read an image area with an impossible stride.
-
-        EXPECTED RESULT:  An error is raised.
-        """
-        if glymur.version.openjpeg_version >= '2.4.0':
-            # The library catches this on its own.
-            expected_error = glymur.lib.openjp2.OpenJPEGLibraryError
-        else:
-            # Image size would be 0 x 0.  We have to manually detect this.
-            expected_error = InvalidJp2kError
-        with self.assertRaises(expected_error):
-            with warnings.catch_warnings():
-                # Only openjpeg 2.4.0 issues warnings
-                warnings.simplefilter('ignore')
-                self.j2k[9:12:4, 9:12:4]
-
-    def test_NR_DEC_p0_04_j2k_85_decode(self):
-        actual = self.j2k[:256, :256]
-        expected = self.j2k_data[:256, :256]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_86_decode(self):
-        actual = self.j2k[:128, 128:256]
-        expected = self.j2k_data[:128, 128:256]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_87_decode(self):
-        actual = self.j2k[10:200, 50:120]
-        expected = self.j2k_data[10:200, 50:120]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_88_decode(self):
-        actual = self.j2k[150:210, 10:190]
-        expected = self.j2k_data[150:210, 10:190]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_89_decode(self):
-        actual = self.j2k[80:150, 100:200]
-        expected = self.j2k_data[80:150, 100:200]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_90_decode(self):
-        actual = self.j2k[20:50, 150:200]
-        expected = self.j2k_data[20:50, 150:200]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_91_decode(self):
-        actual = self.j2k[:256:4, :256:4]
-        expected = self.j2k_quarter_data[0:64, 0:64]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_92_decode(self):
-        actual = self.j2k[:128:4, 128:256:4]
-        expected = self.j2k_quarter_data[:32, 32:64]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_93_decode(self):
-        actual = self.j2k[10:200:4, 50:120:4]
-        expected = self.j2k_quarter_data[3:50, 13:30]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_94_decode(self):
-        actual = self.j2k[150:210:4, 10:190:4]
-        expected = self.j2k_quarter_data[38:53, 3:48]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_95_decode(self):
-        actual = self.j2k[80:150:4, 100:200:4]
-        expected = self.j2k_quarter_data[20:38, 25:50]
-        np.testing.assert_array_equal(actual, expected)
-
-    def test_NR_DEC_p0_04_j2k_96_decode(self):
-        actual = self.j2k[20:50:4, 150:200:4]
-        expected = self.j2k_quarter_data[5:13, 38:50]
-        np.testing.assert_array_equal(actual, expected)
