@@ -3,11 +3,7 @@
 Test suite for printing.
 """
 # Standard library imports ...
-try:
-    import importlib.resources as ir
-except ImportError:  # pragma:  no cover
-    # before 3.7
-    import importlib_resources as ir
+import importlib.resources as ir
 from io import BytesIO, StringIO
 import struct
 import sys
@@ -45,6 +41,18 @@ class TestPrinting(fixtures.TestCommon):
         super(TestPrinting, self).tearDown()
         glymur.reset_option('all')
 
+    def test_empty_file(self):
+        """
+        SCENARIO:  Print the file after with object is constructed, but
+        before data is written to it.
+
+        EXPECTED RESULT:  Just the single line.
+        """
+        filename = self.test_dir_path / 'a.jp2'
+        actual = str(Jp2k(filename))
+        expected = 'File:  a.jp2'
+        self.assertEqual(actual, expected)
+
     def test_bad_color_specification(self):
         """
         Invalid channel type should not prevent printing.
@@ -329,7 +337,7 @@ class TestPrinting(fixtures.TestCommon):
 
         expected = (
             "SIZ marker segment @ (2, 47)\n"
-            "    Profile:  Cinema 2K\n"
+            "    Profile:  2K cinema\n"
             "    Reference Grid Height, Width:  (1080 x 1920)\n"
             "    Vertical, Horizontal Reference Grid Offset:  (0 x 0)\n"
             "    Reference Tile Height, Width:  (1080 x 1920)\n"
@@ -988,10 +996,12 @@ class TestPrinting(fixtures.TestCommon):
 
             actual = str(j.box[5])
 
-        expected = ("UUID Box (uuid) @ (1135519, 76)\n"
-                    "    UUID:  4a706754-6966-6645-7869-662d3e4a5032 (EXIF)\n"
-                    "    UUID Data:  OrderedDict([('ImageWidth', 256), "
-                    "('ImageLength', 512), ('Make', 'HTC')])")
+        expected = (
+            "UUID Box (uuid) @ (1135519, 76)\n"
+            "    UUID:  4a706754-6966-6645-7869-662d3e4a5032 (EXIF)\n"
+            "    UUID Data:  OrderedDict([('ImageWidth', 256), "
+            "('ImageLength', 512), ('Make', 'HTC')])"
+        )
         self.assertEqual(actual, expected)
 
     def test_crg(self):
